@@ -16,12 +16,12 @@ use smallvec::SmallVec;
 #[cfg(feature = "simd_support")]
 use core_simd::u64x8;
 
-#[cfg(all(test, not(miri)))]
-use parking_lot::Mutex;
 #[cfg(test)]
 use std::collections::BTreeSet;
 #[cfg(all(test, not(miri)))]
 use std::sync::atomic::{AtomicUsize, Ordering};
+#[cfg(all(test, not(miri)))]
+use std::sync::Mutex;
 
 pub(crate) const TXID_MASK: u64 = 0x0fff_ffff_ffff_fff0;
 const FLAG_MASK: u64 = 0xf000_0000_0000_0000;
@@ -65,7 +65,7 @@ fn alloc_nid() -> usize {
     let nid: usize = NODE_COUNTER.with(|nc| nc.fetch_add(1, Ordering::AcqRel));
     #[cfg(all(test, not(miri)))]
     {
-        ALLOC_LIST.with(|llist| llist.lock().insert(nid));
+        ALLOC_LIST.with(|llist| llist.lock().unwrap().insert(nid));
     }
     // eprintln!("Allocate -> {:?}", nid);
     nid
@@ -76,7 +76,7 @@ fn release_nid(nid: usize) {
     // println!("Release -> {:?}", nid);
     // debug_assert!(nid != 3);
     {
-        let r = ALLOC_LIST.with(|llist| llist.lock().remove(&nid));
+        let r = ALLOC_LIST.with(|llist| llist.lock().unwrap().remove(&nid));
         assert!(r == true);
     }
 }
@@ -86,7 +86,7 @@ pub(crate) fn assert_released() {
     #[cfg(not(miri))]
     {
         let is_empt = ALLOC_LIST.with(|llist| {
-            let x = llist.lock();
+            let x = llist.lock().unwrap();
             // println!("Remaining -> {:?}", x);
             x.is_empty()
         });
