@@ -6,19 +6,24 @@
 
 use crate::internals::lincowcell::LinCowCellCapable;
 
-use parking_lot::Mutex;
-use rand::Rng;
 use std::borrow::Borrow;
 use std::collections::{BTreeSet, VecDeque};
 use std::fmt::{self, Debug};
-use std::hash::{Hash, Hasher};
 use std::marker::PhantomData;
 use std::ptr;
+use std::sync::Mutex;
 
 use smallvec::SmallVec;
 
 use super::iter::*;
 
+#[cfg(feature = "ahash")]
+use ahash::RandomState;
+#[cfg(not(feature = "ahash"))]
+use std::collections::hash_map::RandomState;
+
+use std::hash::{Hash, Hasher, BuildHasher};
+
 // This defines the max height of our tree. Gives 16777216.0 entries
 // This only consumes 16KB if fully populated
 #[cfg(not(feature = "hashtrie_chonk"))]
@@ -60,7 +65,7 @@ const DEFAULT_BUCKET_ALLOC: usize = 1;
 
 macro_rules! hash_key {
     ($self:expr, $k:expr) => {{
-        let mut hasher = ahash::AHasher::new_with_keys($self.key1, $self.key2);
+        let mut hasher = $self.build_hasher.build_hasher();
         $k.hash(&mut hasher);
         hasher.finish()
     }};
@@ -77,7 +82,7 @@ fn assert_released() {
     #[cfg(not(miri))]
     {
         let is_empty = ALLOC_LIST.with(|llist| {
-            let x = llist.lock();
+            let x = llist.lock().unwrap();
             println!("Remaining -> {:?}", x);
             x.is_empty()
         });
@@ -139,14 +144,14 @@ impl Ptr {
     #[inline(always)]
     fn mark_dirty(&mut self) {
         #[cfg(all(test, not(miri)))]
-        WRITE_LIST.with(|llist| assert!(llist.lock().insert(self.untagged())));
+        WRITE_LIST.with(|llist| assert!(llist.lock().unwrap().insert(self.untagged())));
         self.p |= FLAG_DIRTY
     }
 
     #[inline(always)]
     fn mark_clean(&mut self) {
         #[cfg(all(test, not(miri)))]
-        WRITE_LIST.with(|llist| assert!(llist.lock().remove(&(self.untagged()))));
+        WRITE_LIST.with(|llist| assert!(llist.lock().unwrap().remove(&(self.untagged()))));
         self.p &= MARK_CLEAN
     }
 
@@ -154,7 +159,7 @@ impl Ptr {
     pub(crate) fn as_bucket<K: Hash + Eq + Clone + Debug, V: Clone>(&self) -> &Bucket<K, V> {
         debug_assert!(self.is_bucket());
         #[cfg(all(test, not(miri)))]
-        ALLOC_LIST.with(|llist| assert!(llist.lock().contains(&self.untagged())));
+        ALLOC_LIST.with(|llist| assert!(llist.lock().unwrap().contains(&self.untagged())));
         unsafe { &*((self.p & UNTAG) as *const Bucket<K, V>) }
     }
 
@@ -162,7 +167,7 @@ impl Ptr {
     fn as_bucket_raw<K: Hash + Eq + Clone + Debug, V: Clone>(&self) -> *mut Bucket<K, V> {
         debug_assert!(self.is_bucket());
         #[cfg(all(test, not(miri)))]
-        ALLOC_LIST.with(|llist| assert!(llist.lock().contains(&self.untagged())));
+        ALLOC_LIST.with(|llist| assert!(llist.lock().unwrap().contains(&self.untagged())));
         (self.p & UNTAG) as *mut Bucket<K, V>
     }
 
@@ -174,7 +179,7 @@ impl Ptr {
         debug_assert!(self.is_dirty());
         #[cfg(all(test, not(miri)))]
         WRITE_LIST.with(|llist| {
-            let wlist_guard = llist.lock();
+            let wlist_guard = llist.lock().unwrap();
             assert!(wlist_guard.contains(&self.untagged()))
         });
         unsafe { &mut *((self.p & UNTAG) as *mut Bucket<K, V>) }
@@ -184,7 +189,7 @@ impl Ptr {
     pub(crate) fn as_branch<K: Hash + Eq + Clone + Debug, V: Clone>(&self) -> &Branch<K, V> {
         debug_assert!(self.is_branch());
         #[cfg(all(test, not(miri)))]
-        ALLOC_LIST.with(|llist| assert!(llist.lock().contains(&self.untagged())));
+        ALLOC_LIST.with(|llist| assert!(llist.lock().unwrap().contains(&self.untagged())));
         unsafe { &*((self.p & UNTAG) as *const Branch<K, V>) }
     }
 
@@ -192,7 +197,7 @@ impl Ptr {
     fn as_branch_raw<K: Hash + Eq + Clone + Debug, V: Clone>(&self) -> *mut Branch<K, V> {
         debug_assert!(self.is_branch());
         #[cfg(all(test, not(miri)))]
-        ALLOC_LIST.with(|llist| assert!(llist.lock().contains(&self.untagged())));
+        ALLOC_LIST.with(|llist| assert!(llist.lock().unwrap().contains(&self.untagged())));
         (self.p & UNTAG) as *mut Branch<K, V>
     }
 
@@ -204,7 +209,7 @@ impl Ptr {
         debug_assert!(self.is_dirty());
         #[cfg(all(test, not(miri)))]
         WRITE_LIST.with(|llist| {
-            let wlist_guard = llist.lock();
+            let wlist_guard = llist.lock().unwrap();
             assert!(wlist_guard.contains(&self.untagged()))
         });
         unsafe { &mut *((self.p & UNTAG) as *mut Branch<K, V>) }
@@ -223,7 +228,7 @@ impl Ptr {
     fn free<K: Hash + Eq + Clone + Debug, V: Clone>(&self) {
         // We MUST have allocated this, else it's a double free
         #[cfg(all(test, not(miri)))]
-        ALLOC_LIST.with(|llist| assert!(llist.lock().contains(&self.untagged())));
+        ALLOC_LIST.with(|llist| assert!(llist.lock().unwrap().contains(&self.untagged())));
 
         // It's getting freeeeeedddd
         unsafe {
@@ -236,11 +241,11 @@ impl Ptr {
 
         #[cfg(all(test, not(miri)))]
         if self.is_dirty() {
-            WRITE_LIST.with(|llist| assert!(llist.lock().remove(&(self.untagged()))))
+            WRITE_LIST.with(|llist| assert!(llist.lock().unwrap().remove(&(self.untagged()))))
         };
 
         #[cfg(all(test, not(miri)))]
-        ALLOC_LIST.with(|llist| assert!(llist.lock().remove(&self.untagged())));
+        ALLOC_LIST.with(|llist| assert!(llist.lock().unwrap().remove(&self.untagged())));
     }
 }
 
@@ -251,7 +256,7 @@ impl<K: Hash + Eq + Clone + Debug, V: Clone> From<Box<Branch<K, V>>> for Ptr {
             p: (ptr as usize) | FLAG_BRANCH,
         };
         #[cfg(all(test, not(miri)))]
-        ALLOC_LIST.with(|llist| llist.lock().insert(r.untagged()));
+        ALLOC_LIST.with(|llist| llist.lock().unwrap().insert(r.untagged()));
         r
     }
 }
@@ -263,7 +268,7 @@ impl<K: Hash + Eq + Clone + Debug, V: Clone> From<Box<Bucket<K, V>>> for Ptr {
             p: (ptr as usize) | FLAG_BUCKET,
         };
         #[cfg(all(test, not(miri)))]
-        ALLOC_LIST.with(|llist| llist.lock().insert(r.untagged()));
+        ALLOC_LIST.with(|llist| llist.lock().unwrap().insert(r.untagged()));
         r
     }
 }
@@ -371,8 +376,7 @@ where
     root: Ptr,
     length: usize,
     txid: u64,
-    key1: u128,
-    key2: u128,
+    build_hasher: RandomState,
     k: PhantomData<K>,
     v: PhantomData<V>,
 }
@@ -388,8 +392,7 @@ impl<K: Hash + Eq + Clone + Debug, V: Clone> SuperBlock<K, V> {
             root,
             length: 0,
             txid: 1,
-            key1: rand::thread_rng().gen::<u128>(),
-            key2: rand::thread_rng().gen::<u128>(),
+            build_hasher: RandomState::new(),
             k: PhantomData,
             v: PhantomData,
         }
@@ -412,7 +415,7 @@ impl<K: Hash + Eq + Clone + Debug, V: Clone> LinCowCellCapable<CursorRead<K, V>,
         mut new: CursorWrite<K, V>,
         prev: &CursorRead<K, V>,
     ) -> CursorRead<K, V> {
-        let mut prev_last_seen = prev.last_seen.lock();
+        let mut prev_last_seen = prev.last_seen.lock().unwrap();
         debug_assert!((*prev_last_seen).is_empty());
 
         let new_last_seen = &mut new.last_seen;
@@ -569,10 +572,9 @@ where
     txid: u64,
     length: usize,
     root: Ptr,
-    key1: u128,
-    key2: u128,
     last_seen: Vec<Ptr>,
     first_seen: Vec<Ptr>,
+    build_hasher: RandomState,
     k: PhantomData<K>,
     v: PhantomData<V>,
 }
@@ -585,14 +587,15 @@ impl<K: Clone + Hash + Eq + Debug, V: Clone> CursorWrite<K, V> {
         let last_seen = Vec::with_capacity(16);
         let first_seen = Vec::with_capacity(16);
 
+        let build_hasher = sblock.build_hasher.clone();
+
         CursorWrite {
             txid,
             length,
             root,
             last_seen,
             first_seen,
-            key1: sblock.key1,
-            key2: sblock.key2,
+            build_hasher,
             k: PhantomData,
             v: PhantomData,
         }
@@ -996,25 +999,24 @@ where
     K: Hash + Eq + Clone + Debug,
     V: Clone,
 {
-    key1: u128,
-    key2: u128,
     txid: u64,
     length: usize,
     root: Ptr,
     last_seen: Mutex<Vec<Ptr>>,
+    build_hasher: RandomState,
     k: PhantomData<K>,
     v: PhantomData<V>,
 }
 
 impl<K: Clone + Hash + Eq + Debug, V: Clone> CursorRead<K, V> {
     pub(crate) fn new(sblock: &SuperBlock<K, V>) -> Self {
+        let build_hasher = sblock.build_hasher.clone();
         CursorRead {
             txid: sblock.txid,
             length: sblock.length,
             root: sblock.root,
             last_seen: Mutex::new(Vec::with_capacity(0)),
-            key1: sblock.key1,
-            key2: sblock.key2,
+            build_hasher,
             k: PhantomData,
             v: PhantomData,
         }
